# ~/.config/fish/config.fish: executed by fish for interactive shells.

# This configuration has partly been ported from ~/.bashrc with fish 
# equivalent usage.

# Don't do anything if not running interactively
if not status --is-interactive
    return
end

# Set history options
set -g fish_history_ignore_dups 1  # Don't put duplicate lines in history
set -g fish_history_ignore_space 1 # Don't put lines starting with space in history
set -g fish_history_size 2000      # Set history size
set -g fish_save_history 1         # Append to the history file

# Set the terminal title if in xterm or rxvt
if test "$TERM" = "xterm" -o "$TERM" = "rxvt"
    function fish_title
        echo -ne "\033]0;$USER@$HOSTNAME: $PWD\007"
    end
end

# Enable color support for ls and set aliases
if test -x /usr/bin/dircolors
    if test -r ~/.dircolors
        set -l dircolors_output (dircolors -b ~/.dircolors)
    else
        set -l dircolors_output (dircolors -b)
    end
    # Now, set the environment variables based on the output
    for line in $dircolors_output
        set -gx $line
    end
end

# Set ls aliases
alias ls='lsd'

# Load additional aliases if they exist
if test -f ~/.bash_aliases
    source ~/.bash_aliases
end

# Enable programmable completion features
if test -f /usr/share/fish/completions
    source /usr/share/fish/completions
end

# Set the default editor & manpager
set -gx EDITOR nvim 
set -gx MANPAGER "sh -c 'sed -u -e \"s/\\x1B\[[0-9;]*m//g; s/.\\x08//g\" | bat -p -lman'"

# Use verbose openSSH flags for git
set GIT_SSH_COMMAND "ssh -vvv"

# Update PATH
set -gx PATH "$HOME/.pesde/bin" $PATH

# pnpm setup
set -gx PNPM_HOME "$HOME/.local/share/pnpm"
if not contains "$PNPM_HOME" $PATH
    set -gx PATH "$PNPM_HOME" $PATH
end

# bun setup
set -gx BUN_INSTALL "$HOME/.bun"
set -gx PATH "$BUN_INSTALL/bin" $PATH


set -gx PATH "$HOME/bin" $PATH
set -gx PATH "$HOME/.local/bin" $PATH

# Cargo setup
source "$HOME/.cargo/env.fish"

if status is-login and test -n "$WSL_DISTRO_NAME"
  wsl2-ssh-agent | source
end

zoxide init fish --cmd cd | source
